{% extends "allianceauth/base.html" %}
{% load bootstrap %}
{% load static %}
{% load i18n %}

{% block page_title %}{% translate "Fleet Formatter Tool" %}{% endblock page_title %}
{% block extra_css %}{% endblock extra_css %}

{% block content %}
    <div class="clearfix">
        <h1 class="page-header text-center">{% translate "Fleet Broadcast Formatter Tool" %}</h1>

        <div class="container-fluid">
            <div class="col-md-6 col-md-offset-3">
                <div class="row">
                    {% if generated != "" %}
                        <textarea class="form-control" rows="10" cols="60">{{ generated }}
                        </textarea>
                    {% endif %}
                    <form class="form-signin" role="form" action="" method="POST">
                        {% csrf_token %}
                        {{ form|bootstrap }}
                        <br/>
                        <button class="btn btn-lg btn-primary btn-block" type="submit">{% translate "Format" %}</button>
                        <br/>
                    </form>
                </div>
            </div>
        </div>
    </div>
{% endblock content %}
