{% load i18n %}

<li>
    <a href="{% url 'nightmode' %}?next={{ request.path|urlencode }}">
        <i class="fas {% if NIGHT_MODE %}fa-toggle-on{% else %}fa-toggle-off{% endif %}" aria-hidden="true"></i>
        {% trans "Night Mode" %}
    </a>
</li>
