{% extends "allianceauth/base.html" %}
{% load static %}
{% load i18n %}

{% block page_title %}{% blocktrans with service_name=view.service_name|title %}{{ service_name }} Credentials{% endblocktrans %}{% endblock page_title %}

{% block content %}
    <div class="clearfix">
        <h1 class="page-header text-center">{% blocktrans with service_name=view.service_name|title %}{{ service_name }} Credentials{% endblocktrans %}</h1>
        <div class="container-fluid">
            <div class="col-lg-4 col-lg-offset-4">
                <form class="form-signin">
                    {% for key, value in credentials.items %}
                        <div class="form-group">
                            <label class="control-label" for="id_{{ key }}">{{ key|capfirst }}</label>
                            <input class="form-control" value="{{ value }}" readonly>
                        </div>
                    {% endfor %}
                </form>
                <a href="{% url 'services:services' %}" class="btn btn-lg btn-block btn-primary" title="Continue">{% translate "Continue" %}</a>
            </div>
        </div>
    </div>
{% endblock %}
