@media all {
    html {
        background: url('https://web.ccpgamescdn.com/aws/eveonline/sso/background.jpg') no-repeat center center fixed;
        -moz-background-size: cover;
        -o-background-size: cover;
        -webkit-background-size: cover;
        background-size: cover;
        height: 100%;
    }

    body {
        background-color: rgba(39, 43, 48, .95);
        background-image: none;
        min-height: 100%;
        padding: 1rem;
    }
}
