export declare function hasClassInTree(element: HTMLElement, className: string): any;
export declare function ensureElementInView(container: HTMLElement, element: HTMLElement): void;
export declare function putContent(el: HTMLElement, currentPosition: string, isOpen: boolean): string;
export declare function debounce(func: (...params: any[]) => void, wait?: number, immediate?: boolean): () => void;
export declare function isValueInArrayOfObjects(selected: any, key: string, value: string): boolean;
export declare function highlight(str: string, search: any, className: string): any;
export declare function kebabCase(str: string): string;
